@@ -24,10 +24,6 @@
 #include "about.h"
 #include "configwidget.h"
 
-#ifdef SG_GLOBAL_SHORTCUTS
-#include <QxtGui/QxtGlobalShortcut>
-#endif
-
 #include <QMenu>
 #include <QSystemTrayIcon>
 #include <QDesktopServices>
@@ -52,7 +48,7 @@ public:
     void setConfig(Config *config);
     void updatePixmap(QPixmap *pMap);
     void updateModulesActions(const QList<QAction *> &list);
-    void updateModulesenus(const QList<QMenu *> &list);
+    void updateModulesMenus(const QList<QMenu *> &list);
 
 public Q_SLOTS:
     void showWindow(const QString& str);
@@ -84,15 +80,6 @@ private:
     bool _trayed;
     QIcon appIcon;
 
-#ifdef SG_GLOBAL_SHORTCUTS
-    QxtGlobalShortcut *_fullScreen;
-    QxtGlobalShortcut *_activeWindow;
-    QxtGlobalShortcut *_areaSelection;
-
-    QVector<QxtGlobalShortcut*> _globalShortcuts;
-    QSignalMapper *_globalShortcutSignals;
-#endif
-
     void displatScreenToolTip();
     void createTray();
     void killTray();
@@ -111,11 +98,6 @@ private Q_SLOTS:
     void checkZommMouseArea(bool zoom);
     void updateUI();
     void trayClick(QSystemTrayIcon::ActivationReason reason);
-
-#ifdef SG_GLOBAL_SHORTCUTS
-    void globalShortcutActivate(int type);
-    void globalShortcutBlock(bool state);
-#endif
 };
 
 #endif // MAINWINDOW_H
