@@ -21,7 +21,7 @@
     <message>
         <location filename="../src/core/ui/about.cpp" line="100"/>
         <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
-        <translation>er et plattformuavhenging program for å raskt skape skjermbilder av ditt skrivebord.</translation>
+        <translation>er et plattformuavhenging program for å raskt lage skjermbilder av skrivebordet ditt.</translation>
     </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="102"/>
@@ -86,7 +86,7 @@
     <message>
         <location filename="../src/core/ui/about.cpp" line="142"/>
         <source> Brazilian Portuguese translation</source>
-        <translation> Brasilliansk Portugisisk oversettelse</translation>
+        <translation> Brasiliansk-portugisisk oversettelse</translation>
     </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="143"/>
@@ -154,7 +154,7 @@
     <message>
         <location filename="../src/core/ui/configwidget.cpp" line="186"/>
         <source>Directory %1 does not exist. Do you want to create it?</source>
-        <translation>Mappen %1 finnes ikke. Ønsker du å skape den?</translation>
+        <translation>Mappen %1 finnes ikke. Vil du opprette den?</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.cpp" line="187"/>
@@ -170,7 +170,7 @@
     <message>
         <location filename="../src/core/ui/configwidget.cpp" line="274"/>
         <source>Do you want to reset the settings to the defaults?</source>
-        <translation>Ønsker å du å stille tilbake til standardinnstillinger?</translation>
+        <translation>Vil du tilbakestille til standardinnstillingene?</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.cpp" line="332"/>
@@ -196,57 +196,57 @@
 <context>
     <name>Core</name>
     <message>
-        <location filename="../src/core/core.cpp" line="63"/>
+        <location filename="../src/core/core.cpp" line="64"/>
         <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
         <translation>er et plattformuavhengig program for å raskt ta skjermbilder av ditt skrivebord.</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="67"/>
+        <location filename="../src/core/core.cpp" line="68"/>
         <source>Take a fullscreen screenshot</source>
         <translation>Ta et fullskjerms skjermbilde</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="71"/>
+        <location filename="../src/core/core.cpp" line="72"/>
         <source>Take a screenshot of the active window</source>
         <translation>Ta et skjermbilde av det aktive vinduet</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="75"/>
+        <location filename="../src/core/core.cpp" line="76"/>
         <source>Take a screenshot of a selection of the screen</source>
         <translation>Ta et skjermbilde av et utvalg på skjermen</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="79"/>
+        <location filename="../src/core/core.cpp" line="80"/>
         <source>Run the application with a hidden main window</source>
         <translation>Kjør programmet med et skjult hovedvindu</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="456"/>
+        <location filename="../src/core/core.cpp" line="457"/>
         <source>Saved</source>
         <translation>Lagret</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="456"/>
+        <location filename="../src/core/core.cpp" line="457"/>
         <source>Saved to </source>
         <translation>Lagret i </translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="478"/>
+        <location filename="../src/core/core.cpp" line="479"/>
         <source>Name of saved file is copied to the clipboard</source>
         <translation>Navn på lagret fil kopiert til utklippstavlen</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="484"/>
+        <location filename="../src/core/core.cpp" line="485"/>
         <source>Path to saved file is copied to the clipboard</source>
-        <translation>Filsti til lagret fil er kopiert til utklippsboken</translation>
+        <translation>Filbane til lagret fil er kopiert til utklippstavlen</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="506"/>
+        <location filename="../src/core/core.cpp" line="507"/>
         <source>Copied</source>
         <translation>Kopiert</translation>
     </message>
     <message>
-        <location filename="../src/core/core.cpp" line="506"/>
+        <location filename="../src/core/core.cpp" line="507"/>
         <source>Screenshot is copied to clipboard</source>
         <translation>Skjermbilde kopiert til utklippstavlen</translation>
     </message>
@@ -266,7 +266,7 @@
     <message>
         <location filename="../src/core/ui/mainwindow.ui" line="89"/>
         <source>Type of screenshot</source>
-        <translation>Type skjermbilde</translation>
+        <translation>Skjermbildetype</translation>
     </message>
     <message>
         <location filename="../src/core/ui/mainwindow.ui" line="96"/>
@@ -346,7 +346,7 @@
     <message>
         <location filename="../src/core/ui/mainwindow.cpp" line="48"/>
         <source>Options</source>
-        <translation>Valg</translation>
+        <translation>Alternativer</translation>
     </message>
     <message>
         <location filename="../src/core/ui/mainwindow.cpp" line="49"/>
@@ -412,7 +412,7 @@ for å ta et skjermbilde.</translation>
     <message>
         <location filename="../src/core/regionselect.cpp" line="207"/>
         <source>%1 x %2 pixels </source>
-        <translation>%1 x %2 punkter </translation>
+        <translation>%1 x %2 piksler </translation>
     </message>
 </context>
 <context>
@@ -447,7 +447,7 @@ for å ta et skjermbilde.</translation>
         <location filename="../src/core/ui/configwidget.ui" line="26"/>
         <location filename="../src/core/ui/configwidget.ui" line="601"/>
         <source>Options</source>
-        <translation>Valg</translation>
+        <translation>Alternativer</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="77"/>
@@ -487,7 +487,7 @@ for å ta et skjermbilde.</translation>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="138"/>
         <source>Browse</source>
-        <translation>Se gjennom</translation>
+        <translation>Bla gjennom</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="148"/>
@@ -512,12 +512,12 @@ for å ta et skjermbilde.</translation>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="192"/>
         <source>Default saving image format</source>
-        <translation>Standard bildeformat</translation>
+        <translation>Standard bildelagringsformat</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="211"/>
         <source>Copy file name to the clipboard when saving</source>
-        <translation>Kopier filnavn til utklippsboken ved lagring</translation>
+        <translation>Kopier filnavn til utklippstavlen ved lagring</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="225"/>
@@ -587,7 +587,7 @@ for å ta et skjermbilde.</translation>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="390"/>
         <source>Allow multiple instances of ScreenGrab</source>
-        <translation>Tillat flere utgaver av ScreenGrab</translation>
+        <translation>Tillat flere instanser av ScreenGrab</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="397"/>
@@ -597,13 +597,13 @@ for å ta et skjermbilde.</translation>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="400"/>
         <source>Enable external viewer</source>
-        <translation>Slå på ekstern bildeviser</translation>
+        <translation>Aktiver ekstern bildeviser</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="407"/>
         <source>If this is unchecked, the selected area
 might become larger to fit to outer edges</source>
-        <translation>Hvis dette ikke er markert kan det markerte området
+        <translation>Hvis dette ikke er aktivert kan det markerte området
 bli større for å tilpasses til ytre kanter</translation>
     </message>
     <message>
@@ -619,12 +619,12 @@ bli større for å tilpasses til ytre kanter</translation>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="458"/>
         <source>Tray messages:</source>
-        <translation>Systemkurvsbeskjeder:</translation>
+        <translation>Systemkurvmeldinger:</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="471"/>
         <source>Tray messages display mode</source>
-        <translation>Visningsmodus for systemkurvsbeskjeder</translation>
+        <translation>Visningsmodus for systemkurvmeldinger</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="475"/>
@@ -634,7 +634,7 @@ bli større for å tilpasses til ytre kanter</translation>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="480"/>
         <source>Tray mode</source>
-        <translation>Systemkurvsmodus</translation>
+        <translation>Systemkurvmodus</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="485"/>
@@ -644,12 +644,12 @@ bli større for å tilpasses til ytre kanter</translation>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="497"/>
         <source>Time of display tray messages</source>
-        <translation>Tid å vise systemkurvsbeskjeder</translation>
+        <translation>Tid for visning av systemkurvmeldinger</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="513"/>
         <source>Time to display tray messages</source>
-        <translation>Tid å vise systemkurvsbeskjeder</translation>
+        <translation>Tid å vise systemkurvmeldinger</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="516"/>
@@ -679,17 +679,17 @@ bli større for å tilpasses til ytre kanter</translation>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="586"/>
         <source>New screen</source>
-        <translation>Ny skjerm</translation>
+        <translation>Nytt skjermbilde</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="591"/>
         <source>Save screen</source>
-        <translation>Lagre skjerm</translation>
+        <translation>Lagre skjermbilde</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="596"/>
         <source>Copy screen</source>
-        <translation>Kopier skjerm</translation>
+        <translation>Kopier skjermbilde</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="606"/>
